{% extends 'allianceauth/base-bs5.html' %}
{% load django_bootstrap5 %}

{% block page_title %}Backup 418 Ratting{% endblock page_title %}


{% block content %}
    <div class="col-lg-12">
        <form method="post" enctype="multipart/form-data"> {% csrf_token %}
            <div class="form-group">
                {% bootstrap_form form %}
            </div>
            <button type="submit" class="btn btn-primary">Submit</button>
        </form>
    </div>
{% endblock content %}