# Generated by Django 4.0.7 on 2022-09-12 08:41

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('eveonline', '0016_character_names_are_not_unique'),
        ('allianceauth_pve', '0012_alter_entry_options_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShareUser',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('character', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, related_name='+', to='eveonline.evecharacter')),
                ('share', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='allianceauth_pve.entrycharacter')),
            ],
        ),
        migrations.CreateModel(
            name='EntryCreator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creator_character', models.ForeignKey(on_delete=django.db.models.deletion.RESTRICT, related_name='+', to='eveonline.evecharacter')),
                ('entry', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='allianceauth_pve.entry')),
            ],
        ),
    ]
