# Generated by Django 4.2.16 on 2024-11-21 17:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('outfit418_backup_ratting', '0003_characterauditlogindata'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('audit_corp', "Can audit corp members' alts"), ('find_jeremy', 'Can find Jeremy'))},
        ),
    ]
