# Generated by Django 4.2.8 on 2024-01-04 16:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('outfit418_backup_ratting', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='General',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('audit_corp', "Can audit corp members' alts"),),
                'managed': False,
                'default_permissions': (),
            },
        ),
    ]
